package com.huimv.production.service.impl;

import com.huimv.production.domain.MFattenArea;
import com.huimv.production.domain.MPigWater;
import com.huimv.production.repo.*;
import com.huimv.production.result.Result;
import com.huimv.production.result.ResultStatus;
import com.huimv.production.service.MFattenAreaService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class MFattenAreaServiceImpl implements MFattenAreaService {

	@Autowired
	private MFattenAreaRepository rep;

	@Override
	public Result add(MFattenArea entity){
		if (entity == null){
			return new Result(10002, ResultStatus.addNull);
		}
		try {
			rep.save(entity);
			return new Result(10000, ResultStatus.addSuccess);
		}catch (Exception e){
			return new Result(10001, ResultStatus.addFailed);
		}
	}

	@Override
	public Result remove(Integer[] ids) {
		if (ids == null || ids.length==0){
			return new Result(10002, ResultStatus.deleteNull);
		}
		try {
			for (Integer id : ids) {
				rep.deleteById(id);
			}
			return new Result(10000, ResultStatus.deleteSuccess);
		}catch (Exception e){
			return new Result(10001, ResultStatus.deleteFailed);
		}
	}

	@Override
	public Result update(MFattenArea entity) {
		if (entity == null){
			return new Result(10002, ResultStatus.updateNull);
		}
		try {
			rep.save(entity);
			return new Result(10000, ResultStatus.updateSuccess);
		}catch (Exception e){
			return new Result(10001, ResultStatus.updateFailed);
		}
	}

	@Override
	public Result findAll() {
		try {
			List<MFattenArea> all = rep.findAll();
			return new Result(10000, ResultStatus.findSuccess,all);
		}catch (Exception e){
			return new Result(10001, ResultStatus.findFailed,null);
		}
	}

	@Autowired
	private MPigFeedRepository feedRepository;

	@Autowired
	private MPigWaterRepository pigWaterRepository;

	@Autowired
	private MPigPigpenTemperatureRepository temperatureRepository;

	@Autowired
	private MPigPigpenHumidityRepository humidityRepository;

	@Autowired
	private MElectricQuantityRepository quantityRepository;

	@Autowired
	private MCleanTimesRepository  cleanTimesRepository;

	@Autowired
	private MSmartCountRepository  smartCountRepository;

	@Autowired
	private MSmartWeightRepository  weightRepository;




	@Override
	public Result findAllBy(Integer locationId) {
		try {
			Map endMap = new HashMap();
			endMap.put("PigFeed",feedRepository.findAllByLocationId(locationId));
			endMap.put("pigWater",pigWaterRepository.findAllByLocationId(locationId));
			endMap.put("pigpenTemperature",temperatureRepository.findAllByLocationId(locationId));
			endMap.put("pigpenHumidity",humidityRepository.findAllByLocationId(locationId));
			endMap.put("electricQuantity",quantityRepository.findAllByLocationId(locationId));
			endMap.put("cleanTimes",cleanTimesRepository.findAllByLocationId(locationId));
			endMap.put("smartCount",smartCountRepository.findAllByLocationId(locationId));
			endMap.put("smartWeight",weightRepository.findAllByLocationId(locationId));
			return new Result(10000, ResultStatus.findSuccess,endMap);
		}catch (Exception e){
			return new Result(10001, ResultStatus.findFailed,null);
		}
	}
}
