package com.huimv.production.service.impl;

import com.huimv.production.domain.MPigFeed;
import com.huimv.production.domain.MSowArea;
import com.huimv.production.domain.MSowFeed;
import com.huimv.production.domain.MSowWater;
import com.huimv.production.repo.*;
import com.huimv.production.result.Result;
import com.huimv.production.result.ResultStatus;
import com.huimv.production.service.MSowAreaService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class MSowAreaServiceImpl implements MSowAreaService {

	@Autowired
	private MSowAreaRepository rep;

	@Override
	public Result add(MSowArea entity){
		if (entity == null){
			return new Result(10002, ResultStatus.addNull);
		}
		try {
			rep.save(entity);
			return new Result(10000, ResultStatus.addSuccess);
		}catch (Exception e){
			return new Result(10001, ResultStatus.addFailed);
		}
	}

	@Override
	public Result remove(Integer[] ids) {
		if (ids == null || ids.length==0){
			return new Result(10002, ResultStatus.deleteNull);
		}
		try {
			for (Integer id : ids) {
				rep.deleteById(id);
			}
			return new Result(10000, ResultStatus.deleteSuccess);
		}catch (Exception e){
			return new Result(10001, ResultStatus.deleteFailed);
		}
	}

	@Override
	public Result update(MSowArea entity) {
		if (entity == null){
			return new Result(10002, ResultStatus.updateNull);
		}
		try {
			rep.save(entity);
			return new Result(10000, ResultStatus.updateSuccess);
		}catch (Exception e){
			return new Result(10001, ResultStatus.updateFailed);
		}
	}

	@Override
	public Result findAll() {
		try {
			List<MSowArea> all = rep.findAll();
			return new Result(10000, ResultStatus.findSuccess,all);
		}catch (Exception e){
			return new Result(10001, ResultStatus.findFailed,null);
		}
	}


	@Autowired
	private MSowPigpenTemperatureRepository temperatureRepository;

	@Autowired
	private MSowPigpenHumidityRepository humidityRepository;

	@Autowired
	private MSowFeedRepository feedRepository;

	@Autowired
	private MSowWaterRepository waterRepository;

	@Autowired
	private MSowEntityRepo sowEntityRepo;



	@Override
	public Result findAllBy(Integer locationId) {
		try {
			Map endMap = new HashMap();
			endMap.put("pigpenTemperature",temperatureRepository.findAllByLocationId(locationId));
			endMap.put("pigpenHumidity",humidityRepository.findAllByLocationId(locationId));
			endMap.put("sowFeed",feedRepository.findAllByLocationId(locationId));
			endMap.put("sowWater",waterRepository.findAllByLocationId(locationId));
			endMap.put("sowAll",sowEntityRepo.findAll());
			return new Result(10000, ResultStatus.findSuccess,endMap);
		}catch (Exception e){
			return new Result(10001, ResultStatus.findFailed,null);
		}
	}
}
