package com.huimv.video.service.impl;

import com.huimv.video.domain.MobileMemorandum;
import com.huimv.video.repo.MobileMemorandumRepository;
import com.huimv.video.result.Result;
import com.huimv.video.result.ResultStatus;
import com.huimv.video.service.MobileMemorandumService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

@Service
public class MobileMemorandumServiceImpl implements MobileMemorandumService {

	@Autowired
	private MobileMemorandumRepository rep;

	@Override
	public Result add(MobileMemorandum entity){
		if (entity == null){
			return new Result(10002, ResultStatus.addNull);
		}
		try {
			entity.setDate(new Date());
			rep.save(entity);
			return new Result(10000,ResultStatus.addSuccess);
		}catch (Exception e){
			return new Result(10001,ResultStatus.addFailed);
		}
	}

	@Override
	public Result remove(Integer[] ids) {
		if (ids == null || ids.length==0){
			return new Result(10002,ResultStatus.deleteNull);
		}
		try {
			for (Integer id : ids) {
				rep.deleteById(id);
			}
			return new Result(10000,ResultStatus.deleteSuccess);
		}catch (Exception e){
			return new Result(10001,ResultStatus.deleteFailed);
		}
	}

	@Override
	public Result update(MobileMemorandum entity) {
		if (entity == null){
			return new Result(10002,ResultStatus.updateNull);
		}
		try {
			entity.setDate(new Date());
			rep.save(entity);
			return new Result(10000,ResultStatus.updateSuccess);
		}catch (Exception e){
			return new Result(10001,ResultStatus.updateFailed);
		}
	}

	@Override
	public Result findAll() {
		try {
			List<MobileMemorandum> all = rep.findAll();
			return new Result(10000,ResultStatus.findSuccess,all);
		}catch (Exception e){
			return new Result(10001,ResultStatus.findFailed,null);
		}
	}

	@Override
	public Result findAllById(Integer id) {
		try {
			MobileMemorandum entity = rep.findById(id).get();
			return new Result(10000,ResultStatus.findSuccess,entity);
		}catch (Exception e){
			return new Result(10001,ResultStatus.findFailed,null);
		}
	}

	@Override
	public Result findAllByUserId(Integer userId) {
		List allByUserId = rep.findAllByUserIdOrderByDateDesc(userId);
		return new Result(10000,ResultStatus.findSuccess,allByUserId);
	}
}
