package com.huimv.video.service.impl;

import com.huimv.video.domain.MobileRemember;
import com.huimv.video.repo.MobileRememberRepository;
import com.huimv.video.result.Result;
import com.huimv.video.result.ResultStatus;
import com.huimv.video.service.MobileRememberService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class MobileRememberServiceImpl implements MobileRememberService {

	@Autowired
	private MobileRememberRepository rep;

	@Override
	public Result add(MobileRemember entity){
		if (entity == null){
			return new Result(10002, ResultStatus.addNull);
		}
		try {
			rep.save(entity);
			return new Result(10000,ResultStatus.addSuccess);
		}catch (Exception e){
			return new Result(10001,ResultStatus.addFailed);
		}
	}

	@Override
	public Result remove(Integer[] ids) {
		if (ids == null || ids.length==0){
			return new Result(10002,ResultStatus.deleteNull);
		}
		try {
			for (Integer id : ids) {
				rep.deleteById(id);
			}
			return new Result(10000,ResultStatus.deleteSuccess);
		}catch (Exception e){
			return new Result(10001,ResultStatus.deleteFailed);
		}
	}

	@Override
	public Result update(MobileRemember entity) {
		if (entity == null){
			return new Result(10002,ResultStatus.updateNull);
		}
		try {
			rep.save(entity);
			return new Result(10000,ResultStatus.updateSuccess);
		}catch (Exception e){
			return new Result(10001,ResultStatus.updateFailed);
		}
	}

	@Override
	public Result findAll() {
		try {
			List<MobileRemember> all = rep.findAll();
			return new Result(10000,ResultStatus.findSuccess,all);
		}catch (Exception e){
			return new Result(10001,ResultStatus.findFailed,null);
		}
	}

	@Override
	public Result findAllById(Integer id) {
		try {
			MobileRemember entity = rep.findById(id).get();
			return new Result(10000,ResultStatus.findSuccess,entity);
		}catch (Exception e){
			return new Result(10001,ResultStatus.findFailed,null);
		}
	}

	@Override
	public Result findAllByUserId(Integer userId) {
		List<MobileRemember> byUserId = rep.findByUserId(userId);
		List list =new ArrayList();
		for (MobileRemember mobileRemember : byUserId) {
			Map map = new HashMap();
			map.put("issue",mobileRemember.getIssue());
			map.put("id",mobileRemember.getId());
			list.add(map);
		}
		return new Result(10000,"查询成功",list);
	}

	@Override
	public Result verify(Integer id,String answer) {
		MobileRemember mobileRemember = rep.findById(id).get();
		if (mobileRemember.getAnswer().equals(answer)){
			return new Result(10000,"验证成功");
		}
		return new Result(10001,"验证失败");
	}
}
